@@ -23,6 +23,7 @@ class ImportLoadLibs(unittest.TestCase):
             'libc',
             'libdl',
             'libpcre',
+            'libpcre2-8',
             # libCling and dependencies
             'libCling.*',
             'librt',
@@ -41,6 +42,7 @@ class ImportLoadLibs(unittest.TestCase):
             'oqsprovider', # loaded by libssl on e.g. centos10
             'liboqs', # used by above
             'libtbb',
+            'libtbbmalloc',
             'liburing', # by libRIO if uring option is enabled
             # On centos7 libssl links against kerberos pulling in all dependencies below, removed with libssl1.1.0
             'libgssapi_krb5',
