@@ -375,6 +375,9 @@ void TApplication::GetOptions(Int_t *argc, char **argv)
       } else if (!strcmp(argv[i], "-config")) {
          fprintf(stderr, "ROOT ./configure options:\n%s\n", gROOT->GetConfigOptions());
          Terminate(0);
+      } else if (!strcmp(argv[i], "-a")) {
+         fprintf(stderr, "ROOT splash screen is not visible with root.exe, use root instead.\n");
+         Terminate(0);
       } else if (!strcmp(argv[i], "-b")) {
          MakeBatch();
          argv[i] = null;
@@ -405,16 +408,7 @@ void TApplication::GetOptions(Int_t *argc, char **argv)
          // the web mode is requested
          const char *opt = argv[i] + 5;
          argv[i] = null;
-         if (strcmp(opt, "=off") == 0)
-            gROOT->SetWebDisplay("off");
-         else {
-            printf("\nWARNING!\n");
-            printf("Web mode switch --web is disabled for security reasons.\n");
-            printf("See https://root.cern/about/security/#2023-11-26-open-port-for-control-of-web-gui-allows-read-and-write-access-to-file-system for more information.\n");
-            printf("For environments controlling the security issues you can enable web display by calling\n");
-            printf("gROOT->SetWebDisplay(); in ROOT prompt or in startup scripts\n\n");
-            // gROOT->SetWebDisplay((*opt == '=') ? opt + 1 : "");
-         }
+         gROOT->SetWebDisplay((*opt == '=') ? opt + 1 : "");
       } else if (!strcmp(argv[i], "-e")) {
          argv[i] = null;
          ++i;
@@ -482,10 +476,12 @@ void TApplication::GetOptions(Int_t *argc, char **argv)
          Long_t id, flags, modtime;
          char *arg = strchr(argv[i], '(');
          if (arg) *arg = '\0';
-         char *dir = gSystem->ExpandPathName(argv[i]);
-         // ROOT-9959: we do not continue if we could not expand the path
-         if (!dir) continue;
-         TUrl udir(dir, kTRUE);
+         TString expandedDir(argv[i]);
+         if (gSystem->ExpandPathName(expandedDir)) {
+            // ROOT-9959: we do not continue if we could not expand the path
+            continue;
+         }
+         TUrl udir(expandedDir, kTRUE);
          // remove options and anchor to check the path
          TString sfx = udir.GetFileAndOptions();
          TString fln = udir.GetFile();
@@ -502,11 +498,11 @@ void TApplication::GetOptions(Int_t *argc, char **argv)
                // if directory set it in fWorkDir
                if (pwd == "") {
                   pwd = gSystem->WorkingDirectory();
-                  fWorkDir = dir;
-                  gSystem->ChangeDirectory(dir);
+                  fWorkDir = expandedDir;
+                  gSystem->ChangeDirectory(expandedDir);
                   argv[i] = null;
                } else if (!strcmp(gROOT->GetName(), "Rint")) {
-                  Warning("GetOptions", "only one directory argument can be specified (%s)", dir);
+                  Warning("GetOptions", "only one directory argument can be specified (%s)", expandedDir.Data());
                }
             } else if (size > 0) {
                // if file add to list of files to be processed
@@ -514,7 +510,7 @@ void TApplication::GetOptions(Int_t *argc, char **argv)
                fFiles->Add(new TObjString(path.Data()));
                argv[i] = null;
             } else {
-               Warning("GetOptions", "file %s has size 0, skipping", dir);
+               Warning("GetOptions", "file %s has size 0, skipping", expandedDir.Data());
             }
          } else {
             if (TString(udir.GetFile()).EndsWith(".root")) {
@@ -522,7 +518,7 @@ void TApplication::GetOptions(Int_t *argc, char **argv)
                   // file ending on .root but does not exist, likely a typo
                   // warn user if plain root...
                   if (!strcmp(gROOT->GetName(), "Rint"))
-                     Warning("GetOptions", "file %s not found", dir);
+                     Warning("GetOptions", "file %s not found", expandedDir.Data());
                } else {
                   // remote file, give it the benefit of the doubt and add it to list of files
                   if (!fFiles) fFiles = new TObjArray;
@@ -531,7 +527,7 @@ void TApplication::GetOptions(Int_t *argc, char **argv)
                }
             } else {
                TString mode,fargs,io;
-               TString fname = gSystem->SplitAclicMode(dir,mode,fargs,io);
+               TString fname = gSystem->SplitAclicMode(expandedDir,mode,fargs,io);
                char *mac;
                if (!fFiles) fFiles = new TObjArray;
                if ((mac = gSystem->Which(TROOT::GetMacroPath(), fname,
@@ -550,7 +546,6 @@ void TApplication::GetOptions(Int_t *argc, char **argv)
                }
             }
          }
-         delete [] dir;
       }
       // ignore unknown options
    }
@@ -652,8 +647,10 @@ void TApplication::OpenInBrowser(const TString &url)
    } else {
       // Else the user will have a warning and the URL in the terminal.
       Warning("OpenInBrowser", "The $DISPLAY is not set! Please open (e.g. Ctrl-click) %s\n", url.Data());
+      return;
    }
 #endif
+   Info("OpenInBrowser", "A new tab should have opened in your browser.");
 }
 
 namespace {
@@ -744,6 +741,27 @@ static TString FormatMethodArgsForDoxygen(const TString &scopeName, TFunction *f
 }
 } // namespace
 
+namespace {
+////////////////////////////////////////////////////////////////////////////////
+/// The function returns a TString with the text as an encoded url so that it
+/// can be passed to the function OpenInBrowser
+///
+/// \param[in] text the input text
+/// \return the text appropriately escaped
+
+static TString FormatHttpUrl(TString text)
+{
+   text.ReplaceAll("\n","%0A");
+   text.ReplaceAll("#","%23");
+   text.ReplaceAll(";","%3B");
+   text.ReplaceAll("\"","%22");
+   text.ReplaceAll("`","%60");
+   text.ReplaceAll("+","%2B");
+   text.ReplaceAll("/","%2F");
+   return text;
+}
+} // namespace
+
 namespace {
 ////////////////////////////////////////////////////////////////////////////////
 /// The function checks if a member function of a scope is defined as inline.
@@ -937,6 +955,131 @@ static TString GetUrlForMethod(const TString &scopeName, const TString &methodNa
 }
 } // namespace
 
+////////////////////////////////////////////////////////////////////////////////
+/// It gets the ROOT installation setup as TString
+///
+/// \return a string with several lines
+///
+TString TApplication::GetSetup()
+{
+   std::vector<TString> lines;
+   lines.emplace_back("```");
+   lines.emplace_back(TString::Format("ROOT v%s",
+                                      gROOT->GetVersion()));
+   lines.emplace_back(TString::Format("Built for %s on %s", gSystem->GetBuildArch(), gROOT->GetGitDate()));
+   if (!strcmp(gROOT->GetGitBranch(), gROOT->GetGitCommit())) {
+      static const char *months[] = {"January","February","March","April","May",
+                                     "June","July","August","September","October",
+                                     "November","December"};
+      Int_t idatqq = gROOT->GetVersionDate();
+      Int_t iday   = idatqq%100;
+      Int_t imonth = (idatqq/100)%100;
+      Int_t iyear  = (idatqq/10000);
+
+      lines.emplace_back(TString::Format("From tag %s, %d %s %4d",
+                                         gROOT->GetGitBranch(),
+                                         iday,months[imonth-1],iyear));
+   } else {
+      // If branch and commit are identical - e.g. "v5-34-18" - then we have
+      // a release build. Else specify the git hash this build was made from.
+      lines.emplace_back(TString::Format("From %s@%s",
+                                         gROOT->GetGitBranch(),
+                                         gROOT->GetGitCommit()));
+   }
+   lines.emplace_back(TString::Format("With %s",
+                                      gSystem->GetBuildCompilerVersionStr()));
+   lines.emplace_back("Binary directory: "+ gROOT->GetBinDir());
+   lines.emplace_back("```");
+   TString setup = "";
+   for (auto& line : lines) {
+      setup.Append(line);
+      setup.Append('\n');
+   }
+   setup.Chop(); // trim final `\n`
+   return setup;
+}
+
+////////////////////////////////////////////////////////////////////////////////
+/// It opens a Forum topic in a web browser with prefilled ROOT version
+///
+/// \param[in] type the issue type (only bug supported right now)
+
+void TApplication::OpenForumTopic(const TString &type)
+{
+   // https://meta.discourse.org/t/how-to-create-a-post-clicking-a-link/96197
+
+   if (type == "bug") {
+      //OpenInBrowser("\"https://root-forum.cern.ch/new-topic?title=topic%20title&body=topic%20body&category=category/subcategory&tags=email,planned\"");
+      TString report_template =
+R"(___
+_Please read [tips for efficient and successful posting](https://root-forum.cern.ch/t/tips-for-efficient-and-successful-posting/28292) and [posting code](https://root-forum.cern.ch/t/posting-code-read-this-first/28293)_
+
+### Describe the bug
+<!--
+A clear and concise description of what the wrong behavior is.
+-->
+### Expected behavior
+<!--
+A clear and concise description of what you expected to happen.
+-->
+
+### To Reproduce
+<!--
+Steps to reproduce the behavior:
+1. Your code that triggers the issue: at least a part; ideally something we can run ourselves.
+2. Don't forget to attach the required input files!
+3. How to run your code and / or build it, e.g. `root myMacro.C`, ...
+-->
+
+### Setup
+```
+)"+GetSetup()+
+R"(```
+
+<!--
+Please specify also how you obtained ROOT, such as `dnf install` / binary download / you built it yourself.
+-->
+
+### Additional context
+<!--
+Add any other context about the problem here.
+-->)";
+      report_template = FormatHttpUrl(report_template);
+
+      OpenInBrowser("\"https://root-forum.cern.ch/new-topic?category=ROOT&tags=bug&body="+report_template+"&\"");
+   } else {
+      Warning("OpenForumTopic", "cannot find \"%s\" as type for a Forum topic\n"
+                                 "Available types are 'bug'.", type.Data());
+   }
+}
+
+////////////////////////////////////////////////////////////////////////////////
+/// It opens a GitHub issue in a web browser with prefilled ROOT version
+///
+/// \param[in] type the issue type (bug, feature or improvement)
+
+void TApplication::OpenGitHubIssue(const TString &type)
+{
+   // https://docs.github.com/en/issues/tracking-your-work-with-issues/creating-an-issue#creating-an-issue-from-a-url-query
+
+   if (type == "bug") {
+      OpenInBrowser(
+         "\"https://github.com/root-project/root/issues/new?labels=bug&template=bug_report.yml&root-version=" +
+         FormatHttpUrl(GetSetup()) + "\"");
+   } else if (type == "improvement") {
+      OpenInBrowser("\"https://github.com/root-project/root/issues/"
+                    "new?labels=improvement&template=improvement_report.yml&root-version=" +
+                    FormatHttpUrl(GetSetup()) + "\"");
+   } else if (type == "feature") {
+      OpenInBrowser(
+         "\"https://github.com/root-project/root/issues/new?labels=new+feature&template=feature_request.yml\"");
+   } else {
+      Warning("OpenGitHubIssue",
+              "Cannot find GitHub issue type \"%s\".\n"
+              "Available types are 'bug', 'feature' and 'improvement'.",
+              type.Data());
+   }
+}
 
 ////////////////////////////////////////////////////////////////////////////////
 /// It opens the online reference guide, generated with Doxygen, for the
@@ -1036,10 +1179,53 @@ void TApplication::OpenReferenceGuideFor(const TString &strippedClass)
 
    // Warning message will appear if the user types the function name incorrectly
    // or the function is not a member function of "cl" or any of its base classes.
-   Warning("Help", "cannot find \"%s\" as member of %s or its base classes! Check %s\n", memberName.Data(),
+   Warning("OpenReferenceGuideFor", "cannot find \"%s\" as member of %s or its base classes! Check %s\n", memberName.Data(),
            scopeName.Data(), UrlGenerator(scopeName, scopeType).Data());
 }
 
+////////////////////////////////////////////////////////////////////////////////
+/// The function (".forum <type>") submits a new post on the ROOT forum
+/// via web browser.
+/// \note You can use "bug" as <type>.
+/// \param[in] line command from the command line
+
+void TApplication::Forum(const char *line)
+{
+   // We first check if the user chose a correct syntax.
+   TString strippedCommand = TString(line).Strip(TString::kBoth);
+   if (!strippedCommand.BeginsWith(".forum ")) {
+      Error("Forum", "Unknown command! Use 'bug' after '.forum '");
+      return;
+   }
+   // We remove the command ".forum" from the TString.
+   strippedCommand.Remove(0, 7);
+   // We strip the command line after removing ".help" or ".?".
+   strippedCommand = strippedCommand.Strip(TString::kBoth);
+
+   OpenForumTopic(strippedCommand);
+}
+
+////////////////////////////////////////////////////////////////////////////////
+/// The function (".gh <type>") submits a new issue on GitHub via web browser.
+/// \note You can use "bug", "feature" or "improvement" as <type>.
+/// \param[in] line command from the command line
+
+void TApplication::GitHub(const char *line)
+{
+   // We first check if the user chose a correct syntax.
+   TString strippedCommand = TString(line).Strip(TString::kBoth);
+   if (!strippedCommand.BeginsWith(".gh ")) {
+      Error("GitHub", "Unknown command! Use 'bug', 'feature' or 'improvement' after '.gh '");
+      return;
+   }
+   // We remove the command ".gh" from the TString.
+   strippedCommand.Remove(0, 4);
+   // We strip the command line after removing ".help" or ".?".
+   strippedCommand = strippedCommand.Strip(TString::kBoth);
+
+   OpenGitHubIssue(strippedCommand);
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 /// The function lists useful commands (".help") or opens the online reference
 /// guide, generated with Doxygen (".help scope" or ".help scope::member").
@@ -1057,12 +1243,16 @@ void TApplication::Help(const char *line)
       Printf(" ==============================================================================");
       Printf("   .L <filename>[flags]: load the given file with optional flags like\n"
              "                         + to compile or ++ to force recompile.\n"
-             "                         Type .? TSystem::CompileMacro for a list of all flags.");
+             "                         Type .? TSystem::CompileMacro for a list of all flags.\n"
+             "                         <filename> can also be a shared library; skip flags.");
       Printf("   .(x|X) <filename>[flags](args) :\n"
              "                         same as .L <filename>[flags] and runs then a function\n"
              "                         with signature: ret_type filename(args).");
       Printf("   .credits            : show credits");
       Printf("   .demo               : launch GUI demo");
+      Printf("   .forum bug          : ask for help with a bug or crash at the ROOT forum.");
+      Printf("   .gh [bug|feature|improvement]\n"
+             "                       : submit a bug report, feature or improvement suggestion");
       Printf("   .help Class::Member : open reference guide for that class member (or .?).\n"
              "                         Specifying '::Member' is optional.");
       Printf("   .help edit          : show line editing shortcuts (or .?)");
@@ -1366,7 +1556,7 @@ Longptr_t TApplication::ProcessRemote(const char *line, Int_t *)
    }
    // Attach or start a remote application
    if (user.Length() > 0)
-      hostdir.Insert(0,Form("%s@", user.Data()));
+      hostdir.Insert(0, TString::Format("%s@", user.Data()));
    const char *sc = (script.Length() > 0) ? script.Data() : nullptr;
    TApplication *ap = TApplication::Open(hostdir, dbg, sc);
    if (ap) {
@@ -1426,6 +1616,16 @@ Longptr_t TApplication::ProcessLine(const char *line, Bool_t sync, Int_t *err)
       return 0;
    }
 
+   if (!strncmp(line, ".gh", 3)) {
+      GitHub(line);
+      return 1;
+   }
+
+   if (!strncmp(line, ".forum", 6)) {
+      Forum(line);
+      return 1;
+   }
+
    if (!strncmp(line, ".?", 2) || !strncmp(line, ".help", 5)) {
       Help(line);
       return 1;
