@@ -409,6 +409,30 @@ CreateTargetMachine(const clang::CompilerInstance& CI, bool JITLink) {
   return cantFail(JTMB.createTargetMachine());
 }
 
+#ifdef __APPLE__
+// Forward-declare compiler-rt complex division helpers
+extern "C" {
+void __divsc3();
+void __divdc3();
+}
+
+static SymbolMap GetListOfMacOSCompilerRTSymbols(const LLJIT& Jit) {
+  // Inject symbols that may not be resolved while JIT'ing on macOS
+  static const std::pair<const char*, const void*> NamePtrList[] = {
+      {"__divsc3", (void*)&__divsc3},
+      {"__divdc3", (void*)&__divdc3},
+  };
+  SymbolMap CompilerRTSymbols;
+  for (const auto& NamePtr : NamePtrList) {
+    auto Addr = static_cast<JITTargetAddress>(
+        reinterpret_cast<uintptr_t>(NamePtr.second));
+    CompilerRTSymbols[Jit.mangleAndIntern(NamePtr.first)] =
+        JITEvaluatedSymbol(Addr, JITSymbolFlags::Exported);
+  }
+  return CompilerRTSymbols;
+}
+#endif
+
 #if defined(__linux__) && defined(__GLIBC__)
 static SymbolMap GetListOfLibcNonsharedSymbols(const LLJIT& Jit) {
   // Inject a number of symbols that may be in libc_nonshared.a where they are
@@ -553,6 +577,11 @@ IncrementalJIT::IncrementalJIT(
       absoluteSymbols(GetListOfLibcNonsharedSymbols(*Jit))));
 #endif
 
+#if defined(__APPLE__)
+  cantFail(Jit->getMainJITDylib().define(
+      absoluteSymbols(GetListOfMacOSCompilerRTSymbols(*Jit))));
+#endif
+
   // This replaces llvm::orc::ExecutionSession::logErrorsToStdErr:
   auto&& ErrorReporter = [&Executor, LinkerPrefix, Verbose](Error Err) {
     Err = handleErrors(std::move(Err),
