@@ -19,7 +19,7 @@
 \class RooAbsOptTestStatistic
 \ingroup Roofitcore
 
-RooAbsOptTestStatistic is the abstract base class for test
+Abstract base class for test
 statistics objects that evaluate a function or PDF at each point of a given
 dataset.  This class provides generic optimizations, such as
 caching and precalculation of constant terms that can be made for
@@ -64,7 +64,7 @@ parallelized calculation of test statistics.
 
 #include "ROOT/StringUtils.hxx"
 
-using namespace std;
+using std::endl, std::ostream;
 
 ClassImp(RooAbsOptTestStatistic);
 
@@ -155,7 +155,7 @@ void RooAbsOptTestStatistic::initSlave(RooAbsReal& real, RooAbsData& indata, con
 
   // Mark all projected dependents as such
   if (!projDeps.empty()) {
-    std::unique_ptr<RooArgSet> projDataDeps{static_cast<RooArgSet*>(_funcObsSet->selectCommon(projDeps))};
+    std::unique_ptr<RooArgSet> projDataDeps{_funcObsSet->selectCommon(projDeps)};
     projDataDeps->setAttribAll("projectedDependent") ;
   }
 
@@ -229,7 +229,7 @@ void RooAbsOptTestStatistic::initSlave(RooAbsReal& real, RooAbsData& indata, con
     _dataClone = std::unique_ptr<RooAbsData>{indata.reduce(RooFit::SelectVars(*_funcObsSet),RooFit::CutRange(rangeName))}.release();
     //     cout << "RooAbsOptTestStatistic: reducing dataset to fit in range named " << rangeName << " resulting dataset has " << _dataClone->sumEntries() << " events" << endl ;
   } else {
-    _dataClone = (RooAbsData*) indata.Clone() ;
+    _dataClone = static_cast<RooAbsData*>(indata.Clone()) ;
   }
   _ownData = true ;
 
@@ -298,7 +298,7 @@ void RooAbsOptTestStatistic::initSlave(RooAbsReal& real, RooAbsData& indata, con
   // *********************************************************************
 
   // Remove projected dependents from normalization set
-  if (projDeps.getSize()>0) {
+  if (!projDeps.empty()) {
 
     _projDeps = new RooArgSet;
     projDeps.snapshot(*_projDeps, false) ;
@@ -367,7 +367,8 @@ RooAbsOptTestStatistic::~RooAbsOptTestStatistic()
 double RooAbsOptTestStatistic::combinedValue(RooAbsReal** array, Int_t n) const
 {
   // Default implementation returns sum of components
-  double sum(0), carry(0);
+  double sum(0);
+  double carry(0);
   for (Int_t i = 0; i < n; ++i) {
     double y = array[i]->getValV();
     carry += reinterpret_cast<RooAbsOptTestStatistic*>(array[i])->getCarry();
@@ -570,9 +571,7 @@ void RooAbsOptTestStatistic::optimizeConstantTerms(bool activate, bool applyTrac
         arg->setCacheAndTrackHints(trackNodes);
       }
       // Do not set CacheAndTrack on constant expressions
-      RooArgSet* constNodes = (RooArgSet*) trackNodes.selectByAttrib("Constant",true) ;
-      trackNodes.remove(*constNodes) ;
-      delete constNodes ;
+      trackNodes.remove(*std::unique_ptr<RooAbsCollection>{trackNodes.selectByAttrib("Constant",true)});
 
       // Set CacheAndTrack flag on all remaining nodes
       trackNodes.setAttribAll("CacheAndTrack",true) ;
@@ -591,24 +590,23 @@ void RooAbsOptTestStatistic::optimizeConstantTerms(bool activate, bool applyTrac
       cacheArg->setOperMode(RooAbsArg::AClean) ;
     }
 
-    RooArgSet* constNodes = (RooArgSet*) _cachedNodes.selectByAttrib("ConstantExpressionCached",true) ;
+    std::unique_ptr<RooAbsCollection> constNodes{_cachedNodes.selectByAttrib("ConstantExpressionCached",true)};
     RooArgSet actualTrackNodes(_cachedNodes) ;
     actualTrackNodes.remove(*constNodes) ;
-    if (constNodes->getSize()>0) {
-      if (constNodes->getSize()<20) {
+    if (!constNodes->empty()) {
+      if (constNodes->size()<20) {
         coutI(Minimization) << " The following expressions have been identified as constant and will be precalculated and cached: " << *constNodes << endl ;
       } else {
-        coutI(Minimization) << " A total of " << constNodes->getSize() << " expressions have been identified as constant and will be precalculated and cached." << endl ;
+        coutI(Minimization) << " A total of " << constNodes->size() << " expressions have been identified as constant and will be precalculated and cached." << endl ;
       }
     }
-    if (actualTrackNodes.getSize()>0) {
-      if (actualTrackNodes.getSize()<20) {
+    if (!actualTrackNodes.empty()) {
+      if (actualTrackNodes.size()<20) {
         coutI(Minimization) << " The following expressions will be evaluated in cache-and-track mode: " << actualTrackNodes << endl ;
       } else {
-        coutI(Minimization) << " A total of " << constNodes->getSize() << " expressions will be evaluated in cache-and-track-mode." << endl ;
+        coutI(Minimization) << " A total of " << constNodes->size() << " expressions will be evaluated in cache-and-track-mode." << endl ;
       }
     }
-    delete constNodes ;
 
     // Disable reading of observables that are no longer used
     _dataClone->optimizeReadingWithCaching(*_funcClone, _cachedNodes,requiredExtraObservables()) ;
