@@ -54,7 +54,7 @@ combined in the main thread.
 #include <string>
 #include <stdexcept>
 
-using namespace std;
+using std::endl, std::ostream;
 
 ClassImp(RooAbsTestStatistic);
 
@@ -93,7 +93,7 @@ RooAbsTestStatistic::RooAbsTestStatistic(const char *name, const char *title, Ro
   _paramSet("paramSet","Set of parameters",this),
   _func(&real),
   _data(&data),
-  _projDeps((RooArgSet*)projDeps.Clone()),
+  _projDeps(static_cast<RooArgSet*>(projDeps.Clone())),
   _rangeName(cfg.rangeName),
   _addCoefRangeName(cfg.addCoefRangeName),
   _splitRange(cfg.splitCutRange),
@@ -119,7 +119,7 @@ RooAbsTestStatistic::RooAbsTestStatistic(const RooAbsTestStatistic& other, const
   _paramSet("paramSet","Set of parameters",this),
   _func(other._func),
   _data(other._data),
-  _projDeps((RooArgSet*)other._projDeps->Clone()),
+  _projDeps(static_cast<RooArgSet*>(other._projDeps->Clone())),
   _rangeName(other._rangeName),
   _addCoefRangeName(other._addCoefRangeName),
   _splitRange(other._splitRange),
@@ -176,7 +176,8 @@ double RooAbsTestStatistic::evaluate() const
     if (_mpinterl == RooFit::BulkPartition || _mpinterl == RooFit::Interleave ) {
       ret = combinedValue(reinterpret_cast<RooAbsReal**>(const_cast<std::unique_ptr<RooAbsTestStatistic>*>(_gofArray.data())),_gofArray.size());
     } else {
-      double sum = 0., carry = 0.;
+      double sum = 0.;
+      double carry = 0.;
       int i = 0;
       for (auto& gof : _gofArray) {
         if (i % _numSets == _setNum || (_mpinterl==RooFit::Hybrid && gof->_mpinterl != RooFit::SimComponents )) {
@@ -207,8 +208,8 @@ double RooAbsTestStatistic::evaluate() const
     // Start calculations in parallel
     for (Int_t i = 0; i < _nCPU; ++i) _mpfeArray[i]->calculate();
 
-
-    double sum(0), carry = 0.;
+    double sum(0);
+    double carry = 0.;
     for (Int_t i = 0; i < _nCPU; ++i) {
       double y = _mpfeArray[i]->getValV();
       carry += _mpfeArray[i]->getCarry();
@@ -230,7 +231,9 @@ double RooAbsTestStatistic::evaluate() const
   } else {
 
     // Evaluate as straight FUNC
-    Int_t nFirst(0), nLast(_nEvents), nStep(1) ;
+    Int_t nFirst(0);
+    Int_t nLast(_nEvents);
+    Int_t nStep(1);
 
     switch (_mpinterl) {
     case RooFit::BulkPartition:
@@ -284,7 +287,7 @@ bool RooAbsTestStatistic::initialize()
   if (MPMaster == _gofOpMode) {
     initMPMode(_func,_data,_projDeps,_rangeName,_addCoefRangeName) ;
   } else if (SimMaster == _gofOpMode) {
-    initSimMode((RooSimultaneous*)_func,_data,_projDeps,_rangeName,_addCoefRangeName) ;
+    initSimMode(static_cast<RooSimultaneous*>(_func),_data,_projDeps,_rangeName,_addCoefRangeName) ;
   }
   _init = true;
   return false;
@@ -416,7 +419,7 @@ void RooAbsTestStatistic::initMPMode(RooAbsReal* real, RooAbsData* data, const R
     gof->SetTitle(Form("%s_GOF%d",GetTitle(),i));
 
     ccoutD(Eval) << "RooAbsTestStatistic::initMPMode: starting remote server process #" << i << endl;
-    _mpfeArray[i] = new RooRealMPFE(Form("%s_%zx_MPFE%d",GetName(),(size_t)this,i),Form("%s_%zx_MPFE%d",GetTitle(),(size_t)this,i),*gof,false);
+    _mpfeArray[i] = new RooRealMPFE(Form("%s_%zx_MPFE%d",GetName(),reinterpret_cast<size_t>(this),i),Form("%s_%zx_MPFE%d",GetTitle(),reinterpret_cast<size_t>(this),i),*gof,false);
     //_mpfeArray[i]->setVerbose(true,true);
     _mpfeArray[i]->initialize();
     if (i > 0) {
@@ -464,7 +467,7 @@ void RooAbsTestStatistic::initSimMode(RooSimultaneous* simpdf, RooAbsData* data,
 
     // Retrieve the PDF for this simCat state
     RooAbsPdf* pdf = simpdf->getPdf(catName.c_str());
-    RooAbsData* dset = (RooAbsData*) dsetList->FindObject(catName.c_str());
+    RooAbsData* dset = static_cast<RooAbsData*>(dsetList->FindObject(catName.c_str()));
 
     if (pdf && dset && (0. != dset->sumEntries() || processEmptyDataSets())) {
       ccoutI(Fitting) << "RooAbsTestStatistic::initSimMode: creating slave calculator #" << _gofArray.size() << " for state " << catName
